@@ -108,15 +108,18 @@ class CVM(VM):
         return df
 
     def do_latest(self, action, latest=True):
-        id, tables = itemgetter('id', 'tables')(action)
+        name, tables = itemgetter('id', 'tables')(action)
+        id = name.split('.')[0] if "." in name else name
         self.spark.catalog.setCurrentDatabase(id)
+        group = [DATE_UNIQ] if kCols not in action else get_cols(action, None)
         for key in tables:
-          table_name = tables[key]
-          df = self.spark.table(table_name)
-          if latest:
-              df = unique(df, DATE_COL, [DATE_UNIQ])
-          print(f" - {key}: {table_name}")
-          self.set_frame(key, df)
+          if key not in self.df:
+              table_name = tables[key]
+              df = self.spark.table(table_name)
+              if latest:
+                  df = unique(df, DATE_COL, group)
+              print(f" - {key}: {table_name}")
+              self.set_frame(key, df)
         return self.df
 
     def do_load(self, action):
@@ -190,10 +193,20 @@ class CVM(VM):
         from_key = itemgetter('from')(action)
         df = self.get_frame(from_key)
         cols = get_cols(action, df)
-        if 'where' in action:
-            expression = make_expr(action['where'])
-            self.log(' - do_select: '+expression)
+        if kWhere in action:
+            expression = make_expr(action[kWhere])
+            self.log(f' - do_select[{kWhere}]: '+expression)
             df = df.filter(expression)
+        if kAny in action:
+            expression = make_expr(action[kAny], "OR")
+            self.log(f' - do_select[{kAny}]: '+expression)
+            df = df.filter(expression)
+        if kMatch in action:
+            for col, dict in action[kMatch].items():
+                for table, tcol in dict.items():
+                    self.log(f' - do_select[{kMatch}]: ({col}).leftsemi({table},{tcol})')
+                    dft = self.get_frame(table)
+                    df = df.join(dft, df[col] == dft[tcol], "leftsemi")
         if 'dedupe' in action:
             df = df.drop_duplicates([action['dedupe']])
         column_map = alias_columns(df, cols, from_key)
