@@ -51,9 +51,6 @@ class VM:
 
     def saveable(self):
       saves = self.key_actions(kSave)
-      for id, save in saves.items():
-        if save != 'series':
-          drop_table(self.spark, id)
       return saves
 
     def save(self, id, df, type):
@@ -169,7 +166,7 @@ class VM:
 
     def perform(self, action):
         id, do = itemgetter('id', 'do')(action)
-        print(f'perform[{do}]: {id}')
+        print(f'*perform[{do}]: {id}')
         method = getattr(self, f'do_{do}')
         df = method(action)
         self.sizes[id] = len(df) if isinstance(df, dict) else df.count()
